@@ -1,6 +1,6 @@
 #-*- coding: utf-8 -*-
 
-# Copyright 2010-2012 Calculate Ltd. http://www.calculate-linux.org
+# Copyright 2011-2013 Calculate Ltd. http://www.calculate-linux.org
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -13,12 +13,6 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-#   mode -     read only or writeable variable
-#   value    - default variable value
-#   select   - list of posible values for variable
-#   hide - flag, if it is True, then the variable is not printable
-#   printval - print value of variable
-
 from calculate.lib.datavars import Variable,ReadonlyVariable,VariableError
 import os, glob, sys
 from os import path
@@ -29,7 +23,7 @@ except:
     OpenSSL = None
 
 from calculate.lib.cl_lang import setLocalTranslate
-from calculate.lib.utils.files import readLinesFile
+from calculate.lib.utils.files import readLinesFile,pathJoin, listDirectory
 from calculate.core.server.decorators import Dec
 from calculate.core.server.func import uniq
 #from calculate.api.cert_cmd import find_id_cert
@@ -38,17 +32,10 @@ setLocalTranslate('cl_core3',sys.modules[__name__])
 class VariableClListCertId(ReadonlyVariable):
 
     def get(self):
-        data_path = self.Get('cl_core_data')
-        result = []
-        cert_dir =  os.path.join(data_path, 'client_certs')
-        for filename in os.listdir(cert_dir):
-            if filename.endswith('.crt'):
-                try:
-                    cert_id = filename.split('.')[0]
-                    result.append(cert_id)
-                except:
-                    continue
-        return result
+        cert_dir =  self.Get('cl_core_client_certs_path')
+        return map(lambda x:x[:-4],
+               filter(lambda x:x.endswith('.crt'),
+               listDirectory(cert_dir)))
 
 class VariableClCertId(Variable):
     """
@@ -65,10 +52,6 @@ class VariableClCertId(Variable):
     def choice(self):
         return self.Get('cl_list_cert_id')
 
-#    def get(self):
-#        print type (self.choice()[0])
-#        return self.choice()[0]
-        
     def check(self, cert_id):
 #        if cert_id != 'all':
         try:
@@ -104,22 +87,9 @@ class VariableClCertPerms(Variable):
 
     def get(self):
         cert_id = self.Get('cl_cert_id')
-#        data_path = self.Get('cl_core_data')
-#        cert_dir =  os.path.join(data_path, 'client_certs')
-#        cert_file = os.path.join(cert_dir, '%d.crt' %cert_id)
-
-#        cert = open(cert_file, 'r').read()
-#
-#        #try:
-#        certobj = OpenSSL.crypto.load_certificate \
-#                                       (OpenSSL.SSL.FILETYPE_PEM, cert)
-#        com = certobj.get_extension(certobj.get_extension_count()-1). \
-#                                    get_data()
-#        groups = com.split(':')[1]
-#        groups_list = groups.split(',')
         groups_list = self.Get('cl_cert_groups')
 
-        group_rights = self.Get('cl_core_group_rights')
+        group_rights = self.Get('cl_core_group_rights_path')
         rights = self.Get('cl_core_rights')
         # if group = all and not redefined group all
         if 'all' in groups_list:
@@ -194,6 +164,9 @@ class VariableClCertPerms(Variable):
 
         return results
 
+    def uncompatible(self):
+        return _('You can not change the certificate certificate')
+
 class VariableClCertGroups(Variable):
     """
     Certificate Groups
@@ -207,7 +180,7 @@ class VariableClCertGroups(Variable):
         self.label = _("Certificate groups")
 
     def choice(self):
-        group_rights = self.Get('cl_core_group_rights')
+        group_rights = self.Get('cl_core_group_rights_path')
 
         t = open(group_rights, 'r').read()
         result = []
@@ -221,11 +194,7 @@ class VariableClCertGroups(Variable):
         return result
 
     def get(self):
-        cert_id = self.Get('cl_cert_id')
-
-        data_path = self.Get('cl_core_data')
-        cert_dir =  os.path.join(data_path, 'client_certs')
-        cert_file = os.path.join(cert_dir, '%s.crt' %cert_id)
+        cert_file = self.Get('cl_cert_crt_path')
         if OpenSSL is None:
             return []
 
@@ -243,3 +212,11 @@ class VariableClCertGroups(Variable):
 
     def uncompatible(self):
         return _('You can not change the group certificate')
+
+class VariableClCertCrtPath(Variable):
+    """
+    Путь до сертификата (при указании иденификатора сертификата)
+    """
+    def get(self):
+        return pathJoin(self.Get('cl_core_client_certs_path'),
+                        "%s.crt"%self.Get('cl_cert_id'))
